var indexSectionsWithContent =
{
  0: "_abcdefghijklmnoprstuvwz",
  1: "abcdefhilmnoprstvw",
  2: "b",
  3: "abcdefghiklmnoprstuvwz",
  4: "abcmopstv",
  5: "_abcdefgijklmnoprstuvwz",
  6: "chtw",
  7: "bo",
  8: "b",
  9: "abcdefghilmoprs",
  10: "bdtu"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "related",
  8: "defines",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Friends",
  8: "Macros",
  9: "Modules",
  10: "Pages"
};

